@@ -1,8 +1,6 @@
 from kart import miners, mappers, renderers
-from http.server import SimpleHTTPRequestHandler, ThreadingHTTPServer
-import threading
+from livereload import Server
 import os
-import sys
 import shutil
 import argparse
 
@@ -51,7 +49,16 @@ class Kart:
                 shutil.rmtree(os.path.join(build_location, x))
             else:
                 os.remove(os.path.join(build_location, x))
-        shutil.copytree("static", os.path.join(build_location, "static"))
+        if "static" in os.listdir():
+            shutil.copytree("static", os.path.join(build_location, "static"))
+
+        if "root" in os.listdir():
+            for top_level_file in os.listdir("root"):
+                shutil.copyfile(
+                    os.path.join("root", top_level_file),
+                    os.path.join(build_location, top_level_file),
+                )
+
         for renderer in self.renderers:
             renderer.url_function = self.url
             renderer.render(
@@ -73,15 +80,10 @@ class Kart:
         return self.config["base_url"] + result
 
     def serve(self, port=9000):
-        os.chdir(self.build_location)
-        server_address = ("", port)
-        handler = SimpleHTTPRequestHandler
-        with ThreadingHTTPServer(server_address, handler) as httpd:
-            try:
-                httpd.serve_forever()
-            except KeyboardInterrupt:
-                print("Stopping dev server")
-                sys.exit(0)
+        server = Server()
+        server.watcher.ignore_dirs("_site")
+        server.watch(".", self.build)
+        server.serve(root=self.build_location, port=port, host="0.0.0.0")
 
     def run(self):
         parser = argparse.ArgumentParser()
